<?php
/**
 * @version     2.5.1
 * @package     com_pdjx
 * @copyright   Copyright (C) 2013. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Tools JX <customers@toolsjx.com> - http://www.toolsjx.com
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Pdjx records.
 */
class PaiddownloadsjxModeltransactions extends JModelList
{

    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'tx', 'a.tx',
                'payment_date', 'a.payment_date',
                'txn_type', 'a.txn_type',
                'last_name', 'a.last_name',
                'residence_country', 'a.residence_country',
                'business', 'a.business',
                'payment_type', 'a.payment_type',
            	'payer_status', 'a.payer_status',
                'tax', 'a.tax',
                'payer_email', 'a.payer_email',
                'txn_id', 'a.txn_id',
            	'quantity', 'a.quantity',
                'reciever_email', 'a.reciever_email',
                'first_name', 'a.first_name',
                'payer_id', 'a.payer_id',
                'reciever_id', 'a.reciever_id',
                'item_number', 'a.item_number',
                'payment_status', 'a.payment_status',
            	'mc_fee', 'a.mc_fee',
                'mc_gross', 'a.mc_gross',
                'dwnl', 'a.dwnl',
                'testmode', 'a.testmode',
            	'ip', 'a.ip',
            	'userid', 'a.userid',
            	'productid', 'p.productid',
            	'itemname', 'p.itemname',
            	'country', 'c.country',
            
            	'username', 'u.username',
            	'id', 'a.id',
            );
        }

        parent::__construct($config);
    }


	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $app->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

//		$published = $app->getUserStateFromRequest($this->context.'.filter.state', 'filter_published', '', 'string');
//		$this->setState('filter.state', $published);
        
        
        
		// Load the parameters.
		$params = JComponentHelper::getParams('com_paiddownloadsjx');
		$this->setState('params', $params);

		// List state information.
		parent::populateState();
	}

	/**
	 * Method to get a store id based on model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param	string		$id	A prefix for the store id.
	 * @return	string		A store id.
	 * @since	1.6
	 */
	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id.= ':' . $this->getState('filter.search');
		//$id.= ':' . $this->getState('filter.state');

		return parent::getStoreId($id);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 * @since	1.6
	 */
	protected function getListQuery()
	{
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);
		
		// Select the required fields from the table.
		$query->select(
			$this->getState(
				'list.select',
				'a.*'
			)
		);
		
		// Join over the users for the checked out user.
    	$query->select('u.username AS username');
   		$query->join('LEFT', '#__users AS u ON u.id=a.userid');
		
		$query->from('`#__pdjx_tx` AS a');
		
		$query->select('p.itemname');
		$query->select('p.id AS file_id' );
		$query->select('p.productid' );
		$query->select('c.country' );
		$query->join('LEFT', '#__pdjx_files AS p ON a.item_number=p.id');
		$query->join('LEFT', '#__country_codes AS c ON c.code=a.residence_country');
		
		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
                $query->where('a.txn_id LIKE '.$search.' 
                			OR a.first_name LIKE '.$search.'
                			OR a.last_name LIKE '.$search.'
                			OR a.payer_email LIKE '.$search
                );
			}
		}
		
		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering', 'a.payment_date');
		$orderDirn	= $this->state->get('list.direction', 'desc');
		$query->order($db->escape($orderCol.' '.$orderDirn));
		
		return $query;
	}
	
	public function delete($cid){
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);
		$query->delete("#__pdjx_tx");		
		$query->where("id IN (".implode(',', $cid).")");
		$db->setQuery($query);
		return $db->execute();
	}
}