<?php
#-------------------------------------------------------------------------------
# Copyright (c) 2018 Tools JX.
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the GNU Public License v3.0
# which accompanies this distribution, and is available at
# https://www.gnu.org/licenses/gpl-3.0.en.html
#
# Contributors:
# 	Zavod Skatla/Web-help.me  (initial API and implementation)
# Contact:
# 	toolsjx@web-help.me
#-------------------------------------------------------------------------------
defined('_JEXEC') or die;

class com_gridInstallerScript
{
    private $app, $db;

    public function __construct() {
        $this->db = JFactory::getDBO();
        $this->app = JFactory::getApplication();
    }

    public function install($parent) {
        $this->update();
    }

    public function uninstall($parent) {
        $this->removePlugins();
    }

    public function preflight($type, $parent) {
        if ($type == 'uninstall') {
            $this->removePlugins();
        }
    }

    public function update() {
        $installer = JInstaller::getInstance();
        $path = $installer->getPath('source');

        $this->removePlugins();

        InstallationOfPluginsGrid::install($path . '/plgx_insertgrid', 'Insert Grid: ');
        InstallationOfPluginsGrid::install($path . '/plgx_displaygrid', 'Display Grid: ');

        $this->enablePlugins();
    }

    private function removePlugins() {
        $this->rrmdir(JPATH_PLUGINS . '/content/displaygrid');
        $this->rrmdir(JPATH_PLUGINS . '/editors-xtd/insertgrid');

        $this->db->setQuery("DELETE FROM #__extensions WHERE `type` = 'plugin' AND (element = 'displaygrid' OR element = 'insertgrid') ");
        $this->db->query();

        $this->app->enqueueMessage("Plugins removed");
    }

    private function enablePlugins() {
        $this->db->setQuery("UPDATE #__extensions set enabled = '1' WHERE `type` = 'plugin' AND (element = 'displaygrid' OR element = 'insertgrid')");

        if (!$this->db->query()) {
            $this->app->enqueueMessage('SOME_ERROR_CODE', "Plugins not enabled. Should be enabled manually");
            return;
        }

        $this->app->enqueueMessage("Plugins enabled");
    }

    private function rrmdir($dir) {
        if (!is_dir($dir)) {
            return;
        }

        $objects = scandir($dir);
        foreach ($objects as $object) {
            if ($object != "." && $object != "..") {
                if (filetype($dir . "/" . $object) == "dir") rrmdir($dir . "/" . $object); else unlink($dir . "/" . $object);
            }
        }
        reset($objects);
        rmdir($dir);
    }
}

class InstallationOfPluginsGrid
{
    public static function install($p_dir, $txt) {
        $app = JFactory::getApplication();
        $p_dir = JPath::clean($p_dir);

        // Did you give us a valid directory?
        if (!is_dir($p_dir)) {
            JFactory::getApplication()->enqueueMessage('SOME_ERROR_CODE', JText::_('Package directory is not correct: ' . $p_dir));
            echo JText::_('Please enter a package directory');
            return false;
        }

        // Detect the package type
        $type = JInstallerHelper::detectType($p_dir);

        // Did you give us a valid package?
        if (!$type) {
            JFactory::getApplication()->enqueueMessage('SOME_ERROR_CODE', JText::_('Path does not have a valid package: ' . $p_dir));
            echo JText::_('Path does not have a valid package: ' . $p_dir);

            return false;
        }

        $package['packagefile'] = null;
        $package['extractdir'] = null;
        $package['dir'] = $p_dir;
        $package['type'] = $type;


        // Was the package unpacked?

        if (!$package) {
            echo 'Unable to find install package';
            return false;
        }

        // Get a database connector
        //$db = & JFactory::getDBO();

        // Get an installer instance
        $installer = new JInstaller();

        // Install the package
        if (!$installer->install($package['dir'])) {
            // There was an error installing the package
            $msg = "There was an error installing the plugin";
            $result = false;
        } else {
            // Package installed sucessfully
            $msg = "Installation was successful";
            $result = true;
        }
        $app->enqueueMessage($txt . $msg);

        return $result;
    }
}
